##### RPM PROBLEM WORKAROUNDS

# Suppress automatically generated Requires for Perl libraries.
#global __requires_exclude perl\\\(.*\\\)

#define _unpackaged_files_terminate_build       0 
#define _missing_doc_files_terminate_build      0


Summary: PPD files for PostScript printers
Name:		postscript-ppds
Version:	2006
Release:	%mkrel 18
License:	Distributable
Group:		Publishing
URL:		https://cups.sourceforge.net/
BuildRequires:	cups-common
Requires:	cups-filters ghostscript
BuildArchitectures: noarch

##### SOURCES

# CUPS-Drivers package from Sourceforge, only PPD files for native 
# PostScript printers used
Source200: 	https://downloads.sourceforge.net/project/cups/cups-drivers/0.3.6/cups-drivers-all-0.3.6.tar.bz2

# Perl script to clean up Manufacturer entries in the PPD files, so that
# drivers are sorted by the printer manufacturer in the graphical frontends
Source201: 	cleanppd.pl.bz2

# PPD file for a generic PostScript printer (taken from KUPS)
Source203: 	postscript.ppd.bz2

##### PATCHES

# Fix buggy PPD file
Patch200: cups-drivers-hplj5m_4.ppd.patch



##### BUILD ROOT




##### PACKAGE DESCRIPTION

%description
This package contains PPD files for older PostScript printers.

The PPD files for recent printers are in the foomatic-db package.

Setting up print queues with CUPS or foomatic-rip and these PPD files
makes all features of the printer available, therefore its use is
highly recommended. printerdrake will choose a manufacturer-supplied
PPD file automatically if one for your printer is found.



%prep
# remove old directory
rm -rf $RPM_BUILD_DIR/%{name}-%{version}
mkdir $RPM_BUILD_DIR/%{name}-%{version}

# PPD files for old PostScript printers
%setup -q -T -D -a 200 -n %{name}-%{version}

# Apply patch for buggy ppd file
%patch -P 200 -p0

# Remove CUPS-O-MATIC PPDs
rm -rf cups-drivers-0.3.6/usr/share/cups/model/cups-o-matic

# Remove pstogstoraster-based PPD files, they do not work 
# when printing via Samba. There are other, better PPDs for 
# these printers.
rm -f cups-drivers-0.3.6/usr/share/cups/model/canon/bj10.ppd
rm -f cups-drivers-0.3.6/usr/share/cups/model/hp/djet_890c.ppd
rm -f cups-drivers-0.3.6/usr/share/cups/model/hp/laserjet_gs.ppd

# Remove CUPS PPD files, there are newer versions of them in the CUPS
# package
rm -f cups-drivers-0.3.6/usr/share/cups/model/hp/laserjet.ppd
rm -f cups-drivers-0.3.6/usr/share/cups/model/hp/deskjet.ppd



%build

# Nothing to build



%install

rm -rf $RPM_BUILD_ROOT

# Make directories
install -d $RPM_BUILD_ROOT%{_datadir}/cups/model

# Put the Sourceforge PPDs into CUPS PPD directory
cp -a cups-drivers-0.3.6/usr/share/cups/model/* $RPM_BUILD_ROOT%{_datadir}/cups/model/

# Install PPD file for a generic PostScript printer
bzcat %{SOURCE203} > $RPM_BUILD_ROOT%{_datadir}/cups/model/postscript.ppd

# Correct permissions of PPD file directory
chmod -R u+w,a+rX $RPM_BUILD_ROOT%{_datadir}/cups/model

# "cleanppd.pl" removes unwished PPD files (currently the ones for Birmy
# PowerRIP), fixes broken manufacturer entries, and cleans lines which
# contain only spaces and tabs.

# Uncompress Perl script for cleaning up the PPD files
bzcat %{SOURCE201} > ./cleanppd.pl
chmod a+rx ./cleanppd.pl
# Do the clean-up
find $RPM_BUILD_ROOT%{_datadir}/cups/model -name "*.ppd" -exec ./cleanppd.pl '{}' \;
# Remove PPDs which are not Adobe-compliant and therefore not working with
# CUPS 1.1.20
for ppd in `find $RPM_BUILD_ROOT%{_datadir}/cups/model -name "*.ppd.gz" -print`; do cupstestppd -q $ppd || (rm -f $ppd && echo "$ppd not Adobe-compliant. Deleted."); done



##### GENERAL STUFF

# Correct permissions for all documentation files
for f in %{buildroot}%{_datadir}/cups/model/*/*; do
  chmod a-x $f
done



##### FILES

%files
%{_datadir}/cups/model/*



# Restart the CUPS daemon when it is running, but do not start it when it
# is not running. The restart of the CUPS daemon updates the CUPS-internal
# PPD index

%post
/sbin/service cups condrestart > /dev/null 2>/dev/null || :

%postun
/sbin/service cups condrestart > /dev/null 2>/dev/null || :





%changelog
* Sun Dec 22 2024 pterjan <pterjan> 2006-18.mga10
+ Revision: 2128074
- Rebuild for patchN deprecation

* Fri Nov 04 2022 umeabot <umeabot> 2006-17.mga9
+ Revision: 1902283
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 2006-16.mga8
+ Revision: 1507444
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 2006-15.mga7
+ Revision: 1288053
- Mageia 7 Mass Rebuild

* Thu Oct 12 2017 tv <tv> 2006-14.mga7
+ Revision: 1171296
- requires cups-filters instead of foomatic-filters

* Thu Feb 04 2016 umeabot <umeabot> 2006-13.mga6
+ Revision: 935037
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2006-12.mga5
+ Revision: 746558
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2006-11.mga5
+ Revision: 687744
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Fri Oct 18 2013 umeabot <umeabot> 2006-10.mga4
+ Revision: 517620
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 2006-9.mga3
+ Revision: 378131
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Feb 23 2011 ennael <ennael> 2006-8.mga1
+ Revision: 58042
- clean spec file
- imported package postscript-ppds

